# restiro-spa-material

[![Build Status](https://travis-ci.org/meyt/restiro-spa-material.svg?branch=master)](https://travis-ci.org/meyt/restiro-spa-material)

Default [restiro](https://github.com/meyt/restiro) SPA template.

*Based on [Material Design](https://material.io) specs.*



## Setup
```
npm install
```

### Usage

Development:

```
npm run serve
```

Release build:
```
npm run build
```
